import os
import glob
import numpy as np

def get_snvs(file_name):
    file = open(file_name, "r")
    snvs = set()
    for line in file:
        if line.startswith("#"):
            continue
        row = line.split("\t")
        snvs.add(row[0] + "_" + row[1] + "_" + row[3] + "_" + row[4])
    return snvs

# matrix columns: Time0, Organoid, Tumor
mat = np.matrix([[127, 128, 130], [135, 136, 138], [143, 144, 146], [151, 152, 154], [167, 168, 170]])
ot_tumor = []
ot_time0 = []
time0_tumor = []
for patient_id in range(1, 6):
    patient = "P" + str(patient_id)
    print("Processing " + patient)
    
    # there are 3 samples: 
    # snvs[0]: Time0
    # snvs[1]: Organoid
    # snvs[2]: Tumor
    snvs = []
    for i in range(3):
        dir = "../" + patient + "/PXXXX_" + str(mat[patient_id-1,i]) + "/06-VCF/"
        #fb_file_name = glob.glob(sample + "/06-VCF/freebayes*")[0]
        #strelka_indel = glob.glob(sample + "/06-VCF/Strelka*indels*")[0]
        strelka_snv_file_name = glob.glob(dir + "Strelka*snvs*")[0]
        mutect2_file_name = glob.glob(dir + "mutect*")[0]

        mutect2_snvs = get_snvs(mutect2_file_name)
        strelka_snvs = get_snvs(strelka_snv_file_name)
        snvs.append(mutect2_snvs.intersection(strelka_snvs))

        # output snvs to file
        f = open(dir + "snv_intersection.txt", "w")
        for line in snvs[i]:
            f.write(line + "\n")
        f.close()

    # Tumor vs Organoid
    ret = snvs[1].intersection(snvs[2])
    n2 = len(ret) # shared
    n1 = len(snvs[1]) - n2 # organoid
    n3 = len(snvs[2]) - n2 # tumor
    ot_tumor.append(str(patient_id) + ", Organoid, " + str(n1))
    ot_tumor.append(str(patient_id) + ", Shared, " + str(n2))
    ot_tumor.append(str(patient_id) + ", Tumor, " + str(n3))

    # Time0 vs Organoid
    ret = snvs[1].intersection(snvs[0])
    n2 = len(ret) # shared
    n1 = len(snvs[1]) - n2 # organoid
    n3 = len(snvs[0]) - n2 # time0
    ot_time0.append(str(patient_id) + ", Organoid, " + str(n1))
    ot_time0.append(str(patient_id) + ", Shared, " + str(n2))
    ot_time0.append(str(patient_id) + ", Time0, " + str(n3))

    # just for completeness also output Time0 vs Tumor
    ret = snvs[2].intersection(snvs[0])
    n2 = len(ret) # shared
    n1 = len(snvs[2]) - n2 # tumor
    n3 = len(snvs[0]) - n2 # time0
    time0_tumor.append(str(patient_id) + ", Tumor, " + str(n1))
    time0_tumor.append(str(patient_id) + ", Shared, " + str(n2))
    time0_tumor.append(str(patient_id) + ", Time0, " + str(n3))

# write the lines
output_file = open("../ot_tumor_snv_spectra.csv", "w")
output_file.write("Patient, Variable, Value\n")
for line in ot_tumor:
    output_file.write(line + "\n")
output_file.close()

output_file = open("../ot_time0_snv_spectra.csv", "w")
output_file.write("Patient, Variable, Value\n")
for line in ot_time0:
    output_file.write(line + "\n")
output_file.close()

output_file = open("../time0_tumor_snv_spectra.csv", "w")
output_file.write("Patient, Variable, Value\n")
for line in time0_tumor:
    output_file.write(line + "\n")
output_file.close()