rm(list=ls())

library(ggplot2)

effect_order<-c("frameshift_variant", "stop_gained", "missense_variant", 
                "protein_protein_contact", "structural_interaction_variant",
                "5_prime_UTR_variant", "3_prime_UTR_variant", 
                "upstream_gene_variant", "downstream_gene_variant",
                "intron_variant", 
                "non_coding_transcript_exon_variant")

data_root <- "../"
data_dirs<-matrix(c(127, 128, 130, 135, 136, 138, 143, 144, 146, 151, 152, 154, 167, 168, 170), ncol = 3, byrow = T)
samples<-c("S", "W")

pids<-1:5
dat<-data.frame()
for (pid in pids)
{
  patient<-paste("P", pid, sep="")
  print(patient)
  for (sample_idx in 1:2) {
    path<-paste(patient, "/PXXXX_", data_dirs[pid,sample_idx], "/06-VCF/Annotation/", sep="")
    #setwd(path)
    snv<-read.table(paste(data_root, path, "snv_intersection.txt", sep="/"), header=F, sep=",")
    indel<-read.table(paste(data_root, path, "indel_intersection.txt", sep="/"), header=F, sep=",")
    df<-rbind(snv, indel)
    df<-cbind(patient, samples[sample_idx], df)
    names(df)<-c("Patient", "Sample", "Chr", "Pos", "Genes", "Types")
    n <- dim(df)[1]
    for (i in 1:n) {
      mut_types<-strsplit(as.character(df$Types[i]), ";")[[1]]
      genes<-strsplit(as.character(df$Genes[i]), ";")[[1]]
      types<-data.frame()
      for (j in 1:length(mut_types)) {
        row<-cbind("Effect"=mut_types[j], "Gene"=genes[j])
        types<-rbind(types, row)
        # if ((mut_types[j] == "protein_protein_contact") | (mut_types[j] == "structural_interaction_variant"))
        # {
        #   print(sample_idx)
        #   print(i)
        #   print(mut_types)
        #   print(genes)
        # }
      }
      types$Effect <- factor(types$Effect, levels = effect_order)
      # below code: selects the most deleterious effect if there are multiple
      idx<-order(types$Effect)[1]
      row<-cbind(df[i,1:4], types[idx,])
      dat<-rbind(dat, row)
    }
  }
}

write.csv(dat, file = "snv_driver_genes.csv", quote = F, row.names = F)

# remove genes EGFR, ESR1, PALB2, PIK3CA
exclude_genes<-c("EGFR", "ESR1", "PALB2", "PIK3CA")
dat<-subset(dat, (Gene %in% exclude_genes) == FALSE)

gene_order <- sort(as.character(unique(dat$Gene)))
dat$Gene<-factor(dat$Gene, levels = gene_order)

dat$Effect<-factor(dat$Effect, levels = effect_order)

base_size<-8
font_size<-4
p <- ggplot(dat)
p <- p + geom_tile(aes(x=Gene, y=Sample, fill=Effect, width=1, height=1), color="white")
p <- p + facet_wrap(vars(Patient), nrow = 5, ncol = 1, strip.position = "left")
p <- p + theme_bw()
p <- p + scale_x_discrete(limits = gene_order, labels=gene_order)
p <- p + theme(axis.title = element_blank())
p <- p + theme(strip.text.y = element_text(angle = 180), strip.placement = "outside", strip.background.y = element_blank())
p <- p + theme(axis.text.x = element_text(angle = 90, vjust = 0.5, hjust = 1, size=font_size))
p <- p + theme(axis.ticks = element_blank(), axis.text.x = element_text(size = base_size, colour = "black"))
p <- p + theme(panel.spacing.y = unit(0, "lines"), panel.grid=element_blank())
p <- p + theme(legend.title = element_blank())
p <- p + coord_fixed()
p
ggsave(filename = "snv_wo.pdf", p, width = 11, height = 5, units = "in")

