library(tsne)

library(biomaRt)
library(ggplot2)
library(dplyr)
library(GenomicRanges)
library(rgl)

setwd("~/Dropbox/Hartman/")

source("~/Dropbox/Hartman/R/helper_functions.R")

ensembl=useMart("ensembl")
listDatasets(ensembl)
ensembl <- useDataset("hsapiens_gene_ensembl",mart=ensembl)
#listDatasets(ensembl)

ensembl <- useMart("ensembl",dataset="hsapiens_gene_ensembl")
filters <- listFilters(ensembl)
filters[1:5,]

attributes <- listAttributes(ensembl)
attributes[1:10,]

gene_list<-read.csv("~/Dropbox/Hartman/BC_driver_genes.csv", header=F)
genes<-getBM(attributes = c("hgnc_symbol","chromosome_name", "start_position", "end_position"),
         filters = "hgnc_symbol", values = gene_list$V1,mart = ensembl)
dim(genes)

chrs<-paste(1:22, "", sep="")
chrs<-c(chrs, "X", "Y", "MT")
genes<-genes[genes$chromosome_name %in% chrs,]
dim(genes)
sum(gene_list$V1 %in% genes$hgnc_symbol)
genes$chromosome_name<-paste("chr", genes$chromosome_name, sep="")
gene_ranges <- IRanges(start = genes$start_position, end = genes$end_position)
n_genes <- dim(genes)[1]

write.table(genes$hgnc_symbol, file = "~/Dropbox/Hartman/tsne_genes.csv", row.names = F, quote = F, col.names = F)

# read vcf files
sample_names<-c("S", "W", "T")
n_samples<-length(sample_names)
data_dirs<-matrix(c(127, 128, 130, 135, 136, 138, 143, 144, 146, 151, 152, 154, 167, 168, 170), ncol = 3, byrow = T)
patient_ids<-1:5
col_names<-c("chr", "pos", "ref", "alt")

X<-matrix(0, nrow = n_samples*5, ncol = 2*n_genes)
data_info<-data.frame()
for (patient_id in patient_ids)
{
  patient<-paste("P", patient_ids[patient_id], sep="")
  setwd(paste("~/Dropbox/Hartman/", patient, sep=""))
  for (sample_idx in 1:n_samples)
  {
    data_dir <- paste("PXXXX_", data_dirs[patient_id, sample_idx], sep="")
    # read snv_intersection.txt
    dat<-read.table(paste(data_dir, "/06-VCF/snv_intersection.txt", sep=""), header=F, sep = "_")
    colnames(dat) <- col_names
    
    # read cnv data
    cnv_file <- paste(data_dir, ".clean.dedup.bam_CNVs", sep="")
    data_path <- paste(data_dir, "05-CNA", cnv_file, sep="/")
    cnv<-read.table(data_path, sep="\t", header=F)
    colnames(cnv)<-c("Chromosome", "start_position", "end_position", "cn", "status")
    cnv$Chromosome <- paste("chr", cnv$Chromosome, sep="")

    x <- rep(0, n_genes)
    y <- rep(0, n_genes)
    for (n in 1:n_genes)
    {
      gene<-genes[n,]
      nsnvs <- sum(gene$start_position <= dat$pos & gene$end_position >= dat$pos & gene$chromosome_name == dat$chr)
      x[n] <- as.numeric(nsnvs > 0)
      
      cnv_temp <- subset(cnv, cnv$Chromosome == gene$chromosome_name)
      target_range <- c(gene$start_position, gene$end_position)
      candidate_ranges <- as.matrix(cnv_temp[,c("start_position", "end_position")])
      overlap_idx <- overlaps2(target_range, candidate_ranges)
      ncnvs <- sum(overlap_idx)
      y[n] <- as.numeric(ncnvs > 0)
    }
    xx<-c(x, y)
    X[n_samples*(patient_id-1) + sample_idx,]<-xx
  }
  data_info<-rbind(data_info, data.frame("Patient" = patient, "Sample" = c("S", "W", "T")))
}  

XX<-dist(X)
Y<-tsne(XX, k = 2, perplexity = 3, whiten = FALSE, max_iter = 10000)
data_info$Dim1<-Y[,1]
data_info$Dim2<-Y[,2]
data_info<-subset(data_info, Sample == "S" | Sample == "W")
p<-ggplot(data_info, aes(Dim1, Dim2, col=Patient, shape=Sample)) + geom_point(size=5)
p<-p + theme_bw()
ggsave(filename = "~/Dropbox/Hartman/tsne.pdf", p)
