compile_res_lm <- function(x, prefix = NULL, suffix = NULL) {
  res_tbl <- cbind(
    tibble(
      coef = rownames(summary(x)$coefficients), 
      estimate = summary(x)$coefficients[, "Estimate"]),
    confint(x)[, c("2.5 %", "97.5 %"), drop = FALSE],
    summary(x)$coefficients[, "Pr(>|t|)", drop = FALSE]) %>%
    as_tibble() %>%
    (function(x) {
      names(x) <- c("coef", "est", "CI_lo", "CI_up", "P")
      x
    }) %>%
    mutate(
      P = cut(
        P,
        breaks = c(-Inf, 0.001, 0.01, 0.05, 0.1, 1),
        labels = c("***", "**", "*", ".", " "))
    ) %>%
    filter(coef != "(Intercept)") %>%
    dplyr::select(coef, est, P)
  
  if (!is.null(prefix)) {
    res_tbl <- res_tbl %>%
      (function(x) {
        names(x) <- c("coef",
          paste0(prefix, c("est", "P")))
        x
      })
  }
  
  if (!is.null(suffix)) {
    res_tbl <- res_tbl %>%
      (function(x) {
        names(x) <- c("coef",
          paste0(c("est", "P"), suffix))
        x
      })
  }
  
  res_tbl 
}