clin <- df_clin[1:16, c(1, 8:15)] %>%
  as.data.frame()
colnames(clin) <- c("id0", "erval", "prval", "her2val", "her2stat", "ki67val", "subtype", "primary", "neoadj")

clin$erval <- as.numeric(clin$erval)
clin$prval <- as.numeric(clin$prval)
clin$her2val[clin$erval %in% "-"] <- NA
clin$ki67val[clin$prval %in% "-"] <- NA
clin$her2val[clin$her2val %in% "-"] <- NA
clin$ki67val[clin$ki67val %in% "-"] <- NA
clin$ki67val <- as.numeric(clin$ki67val)
clin$primary <- trimws(clin$primary)
clin$neoadj <- trimws(clin$neoadj)

clin <- clin %>%
  mutate(
    subjnum = as.integer(gsub("RNA", "", id0, fixed = TRUE)),
    subjid = formatC(subjnum, width=2, format="d"), 
    erstat = factor(erval >= 10, 
      levels = c(FALSE, TRUE), labels = c("ER-", "ER+")), 
    prstat = factor(prval >= 10, 
      levels = c(FALSE, TRUE), labels = c("PR-", "PR+")), 
    her2stat = factor(her2stat=="pos",
                      levels = c(FALSE, TRUE), 
                      labels=c("HER2-", "HER2+"))
  ) %>%
  dplyr::select(subjnum, subjid, 
    erval, erstat, prval, prstat, her2val, her2stat, ki67val, subtype,
    primary, neoadj)

lkup <- c(
  "ER+/PR+/HER2+" = "HER2+", 
  "ER+/PR-/HER2+" = "HER2+", 
  "ER-/PR+/HER2+" = "HER2+", 
  "ER-/PR-/HER2+" = "HER2+", 
  "ER+/PR+/HER2+" = "HER2+", 
  "ER+/PR+/HER2-" = "ER+/HER2-",
  "ER+/PR-/HER2-" = "ER+/HER2-", 
  "ER-/PR-/HER2-" = "TNBC", 
  "ER-/PR+/HER2-" = NA,
  "NA/NA/NA" = NA)
clin$trigrp <- factor(
  lkup[with(clin, paste(erstat, prstat, her2stat, sep = "/"))], 
  levels = c("ER+/HER2-", "HER2+", "TNBC"))

clin$subtype <- factor(clin$subtype,
                       levels = c("LA", "LB/H2-", "LB/H2+", "TNBC"))
