samples_data <- df_samples[grepl("^R", df_samples$"User ID"), ] %>%
  as.data.frame()
colnames(samples_data) <- gsub(" ", "_", colnames(samples_data), fixed = TRUE)

## Initial munging based on User_ID
condcd_lkup <- c(
  "Tid0" = "T0",
  "Time0" = "T0", 
  "Time 0" = "T0", 
  "CTRL" = "CTRL",
  "Ctrl" = "CTRL",
  "4OHT" = "4OHT", 
  "NDT" = "NDT")
samples_data <- samples_data %>%
  separate(User_ID, c("id0", "condcd0"), sep = "-", remove = FALSE) %>%
  mutate(
    samplenam = User_ID, 
    subjnum = as.integer(gsub("R", "", gsub("RNA ", "R", id0, fixed = TRUE))),
    # subjid = formatC(subjnum, width=2, format="d", flag="0"),
    subjid = formatC(subjnum, width=2, format="d"), 
    condcd = factor(condcd_lkup[condcd0], 
      levels = c("T0", "CTRL", "4OHT", "NDT")), 
    samplecd = paste(subjid, condcd, sep = "_")) %>%
  (function(x) as.data.frame(x, row.names = x$samplecd))

## Additional munging
samples_data <- samples_data %>%
  mutate(
    cellcd = factor(condcd %in% "T0", 
      levels = c(TRUE, FALSE), 
      labels = c("scraping", "exvivo")), 
    cell = factor(condcd %in% "T0", 
      levels = c(TRUE, FALSE), 
      labels = c("Scraping", "Ex vivo")), 
    tptcd = factor(condcd %in% "T0", 
      levels = c(TRUE, FALSE), 
      labels = c("T0", "T1")), 
    tpt = factor(condcd %in% "T0", 
      levels = c(TRUE, FALSE), 
      labels = c("0 hrs", "48 hrs")), 
    armcd = factor(as.character(condcd), 
      levels = c("CTRL", "4OHT", "NDT")),
    arm = factor(as.character(condcd), 
      levels = c("CTRL", "4OHT", "NDT"), 
      labels = c("Control", "4-hydroxy-tamoxifen", "Endoxifen"))) %>%
  (function(x) as.data.frame(x, row.names = x$samplecd))
