## Gene modules, Desmedt08CCR:
## http://www.ncbi.nlm.nih.gov/pubmed/18698033
##
## * ESR1 (estrogen receptor pathway)
## * ERBB2 (her2/neu receptor pathway)
## * AURKA (proliferation)
## * STAT1 (immune response)
## * PLAU (tumor invasion)
## * VEGF (angogenesis)
## * CASP3 (apoptosis)

require("genefu")
data("mod1", package = "genefu")

allentrezids <- unique(purrr::reduce(mod1, rbind)$EntrezGene.ID)

esetnams  <- "exvivo"
for (esetnam in esetnams) {
  eset <- get(esetnam)
  
  eset2 <- eset[fData(eset)$entrezid %in% allentrezids,]
  eset2 <- eset2[apply(exprs(eset2), 1, function(x) all(!is.na(x))), ]
  eset2 <- averageExprsByFDataVar(eset2, "entrezid")
  fData(eset2)$EntrezGene.ID <- fData(eset2)$entrezid  # as genefu wants it
  
  ## Derive relative expression
  exprs(eset2) <- sweep(exprs(eset2), 1, apply(exprs(eset2), 1, "median"))
  
  ## Derive module scores
  for (modnamcd in names(mod1)) {
    x <- sig.score(
      x = mod1[[modnamcd]],
      data = t(exprs(eset2)),
      annot = fData(eset2),
      do.mapping = TRUE,
      signed = TRUE)
    modnam <- paste0(modnamcd, "_module")
    pData(eset)[, modnam] <- x$score[sampleNames(eset)]
  }
  
  stopifnot(validObject(eset))
  assign(esetnam, eset)
}
