ProjectTemplate::reload.project()

stopifnot(exists("tab_de1"))

rnk_file <- file.path("reports", "gsea", "de1_exvivo_vs_surgery.rnk")

rnk_de1 <- tab_de1 %>%
  filter(!is.na(entrezid)) %>%
  mutate(score = sign(logFC) * sqrt(max(0, LR))) %>%  # see explanation below
  dplyr::select(entrezid, score) %>%
  group_by(entrezid) %>%
  summarize(score = mean(score)) %>%  # temporary hackish work-around
  ungroup()

## Explanation
## -----------
##
## Under the null-hypothesis (H_0), the log-likelihood ratio statistic (LR) is 
## assymptotically chi-square distributed with 1 degree of freedom since we test 
## one coefficient in the tag-wise model. 
## Therefore, the calculated score sign(logFC) * sqrt(LR) is assymptotically 
## normal distributed under H_0 and carries information about direction of 
## differential expression. 

write.table(rnk_de1,
  file = rnk_file,
  quote = FALSE, sep = "\t", row.names = FALSE, col.names = FALSE)


# gsea_jar <- "C:/Users/emmsif/OneDrive - KI.SE/OnkPat/projects/JohanHartman/ExVivoModel/others/JohnLovrot/resources/software/gsea-3.0.jar"
# rnd_seed <- 20101216
# output_dir <- file.path("reports", "gsea")
# 
# ## Hallmarks gene-set collection
# ## http://software.broadinstitute.org/gsea/msigdb/collections.jsp#H
# gmt_file <- "C:/Users/emmsif/OneDrive - KI.SE/OnkPat/projects/JohanHartman/ExVivoModel/others/JohnLovrot/resources/msigdb/6.2/h.all.v6.2.entrez.gmt"
# output_name <- "de1_exvivo_vs_surgery_h"
# cmd <- paste("java -Xmx2g -cp", gsea_jar, "xtools.gsea.GseaPreranked",
#   "-gmx", gmt_file,
#   "-rnk", rnk_file,
#   "-rnd_seed", rnd_seed,
#   "-rpt_label", output_name,
#   "-out", output_dir,
#   "-create_svgs true")
# system(cmd, ignore.stdout = TRUE)

# java -Xmx2g -cp "C:\Users\emmsif\OneDrive - KI.SE\OnkPat\projects\JohanHartman\ExVivoModel\others\JohnLovrot\resources\software\gsea-3.0.jar" xtools.gsea.GseaPreranked -gmx "C:\Users\emmsif\OneDrive - KI.SE\OnkPat\projects\JohanHartman\ExVivoModel\others\JohnLovrot\resources\msigdb\6.2\h.all.v6.2.entrez.gmt" -rnk "C:\Users\emmsif\OneDrive - KI.SE\OnkPat\projects\JohanHartman\ExVivoModel\others\JohnLovrot\ProjectsMaExvivo\reports\gsea\de1_exvivo_vs_surgery.rnk" -rpt_label de1_exvivo_vs_surgery_h -rnd_seed 20101216 -out "C:\Users\emmsif\OneDrive - KI.SE\OnkPat\projects\JohanHartman\ExVivoModel\others\JohnLovrot\projects-ma-exvivo\reports\gsea "


# gsea-cli.bat GSEAPreranked -gmx C:\Users\emmsif\OneDrive - KI.SE\OnkPat\projects\JohanHartman\ExVivoModel\others\JohnLovrot\resources\msigdb\7.1\h.all.v7.1.entrez.gmt -collapse No_Collapse -mode Max_probe -norm meandiv -nperm 1000 -rnk C:\Users\emmsif\OneDrive - KI.SE\OnkPat\projects\JohanHartman\ExVivoModel\others\JohnLovrot\ProjectsMaExvivo\reports\gsea\de1_exvivo_vs_surgery.rnk -scoring_scheme weighted -rpt_label de1_exvivo_vs_surgery_h -create_svgs true -include_only_symbols true -make_sets true -plot_top_x 20 -rnd_seed 20101216 -set_max 500 -set_min 15 -zip_report false -out C:\Users\emmsif\OneDrive - KI.SE\OnkPat\projects\JohanHartman\ExVivoModel\others\JohnLovrot\ProjectsMaExvivo\reports\gsea
