ProjectTemplate::reload.project()

stopifnot(exists("tab_de2_4oht_v_ctrl"))

rnk_file <- file.path("reports", "gsea", "de2_4oht_v_ctrl.rnk")

rnk_de2_4oht_v_ctrl <- tab_de2_4oht_v_ctrl %>%
  filter(!is.na(entrezid)) %>%
  rowwise() %>%
  mutate(score = sign(logFC) * sqrt(max(0, LR))) %>%  # see explanation below
  dplyr::select(entrezid, score) %>%
  group_by(entrezid) %>%
  summarize(score = mean(score)) %>%  # temporary hackish work-around
  ungroup()

## Explanation
## -----------
##
## Under the null-hypothesis (H_0), the log-likelihood ratio statistic (LR) is 
## assymptotically chi-square distributed with 1 degree of freedom since we test 
## one coefficient in the tag-wise model. 
## Therefore, the calculated score sign(logFC) * sqrt(LR) is assymptotically 
## normal distributed under H_0 and carries information about direction of 
## differential expression. 

write.table(rnk_de2_4oht_v_ctrl,
  file = rnk_file,
  quote = FALSE, sep = "\t", row.names = FALSE, col.names = FALSE)

# gsea_jar <- "C:/Users/emmsif/OneDrive - KI.SE/OnkPat/projects/JohanHartman/ExVivoModel/others/JohnLovrot/resources/software/gsea-3.0.jar"
# rnd_seed <- 20101216
# output_dir <- file.path("reports", "gsea")
# 
# ## Hallmarks gene-set collection
# ## http://software.broadinstitute.org/gsea/msigdb/collections.jsp#H
# gmt_file <- "C:/Users/emmsif/OneDrive - KI.SE/OnkPat/projects/JohanHartman/ExVivoModel/others/JohnLovrot/resources/msigdb/6.2/h.all.v6.2.entrez.gmt"
# output_name <- "de2_4oht_v_ctrl_h"
# cmd <- paste("java -Xmx2g -cp", gsea_jar, "xtools.gsea.GseaPreranked",
#   "-gmx", gmt_file,
#   "-rnk", rnk_file,
#   "-rnd_seed", rnd_seed,
#   "-rpt_label", output_name,
#   "-out", output_dir,
#   "-create_svgs true")
# system(cmd, ignore.stdout = TRUE)

# ## Canonical pathways gene-set collection
# ## http://software.broadinstitute.org/gsea/msigdb/collections.jsp#CP
# gmt_file <- "C:/Users/emmsif/OneDrive - KI.SE/OnkPat/projects/JohanHartman/ExVivoModel/others/JohnLovrot/resources/msigdb/6.2/c2.cp.v6.2.entrez.gmt"
# output_name <- "de2_4oht_v_ctrl_cp"
# cmd <- paste("java -Xmx2g -cp", gsea_jar, "xtools.gsea.GseaPreranked",
#   "-gmx", gmt_file,
#   "-rnk", rnk_file,
#   "-rnd_seed", rnd_seed,
#   "-rpt_label", output_name,
#   "-out", output_dir,
#   "-collapse false",
#   "-create_svgs true")
# system(cmd, ignore.stdout = TRUE)
# 
# ## GO biological process gene-set collection
# ## http://software.broadinstitute.org/gsea/msigdb/collections.jsp#BP
# gmt_file <- "C:/Users/emmsif/OneDrive - KI.SE/OnkPat/projects/JohanHartman/ExVivoModel/others/JohnLovrot/resources/msigdb/6.2/c5.bp.v6.2.entrez.gmt"
# output_name <- "de2_4oht_v_ctrl_bp"
# cmd <- paste("java -Xmx2g -cp", gsea_jar, "xtools.gsea.GseaPreranked",
#   "-gmx", gmt_file,
#   "-rnk", rnk_file,
#   "-rnd_seed", rnd_seed,
#   "-rpt_label", output_name,
#   "-out", output_dir,
#   "-collapse false",
#   "-create_svgs true")
# system(cmd, ignore.stdout = TRUE)
# 
# ## GO cellular component gene-set collection
# ## http://software.broadinstitute.org/gsea/msigdb/collections.jsp#CC
# gmt_file <- "C:/Users/emmsif/OneDrive - KI.SE/OnkPat/projects/JohanHartman/ExVivoModel/others/JohnLovrot/resources/msigdb/6.2/c5.cc.v6.2.entrez.gmt"
# output_name <- "de2_4oht_v_ctrl_cc"
# cmd <- paste("java -Xmx2g -cp", gsea_jar, "xtools.gsea.GseaPreranked",
#   "-gmx", gmt_file,
#   "-rnk", rnk_file,
#   "-rnd_seed", rnd_seed,
#   "-rpt_label", output_name,
#   "-out", output_dir,
#   "-collapse false",
#   "-create_svgs true")
# system(cmd, ignore.stdout = TRUE)
